aboutsummaryrefslogtreecommitdiffstats
path: root/gtk/graph_analysis.c
diff options
context:
space:
mode:
authorGuy Harris <guy@alum.mit.edu>2006-05-22 07:29:40 +0000
committerGuy Harris <guy@alum.mit.edu>2006-05-22 07:29:40 +0000
commit92552c2d765dcf89883392fcd11556d54f2843e5 (patch)
treebb7476c5cd4845fce70a943d87cab8ddb12fe41d /gtk/graph_analysis.c
parent4c4664721edb7f9f7b9886a881d913e4dff2043a (diff)
Get rid of a bunch of "Ethereal"s and "ethereal"s in comments, GUI
strings, and function names. svn path=/trunk/; revision=18205
Diffstat (limited to 'gtk/graph_analysis.c')
-rw-r--r--gtk/graph_analysis.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/gtk/graph_analysis.c b/gtk/graph_analysis.c
index e1b0bbbeeb..35dfa82e28 100644
--- a/gtk/graph_analysis.c
+++ b/gtk/graph_analysis.c
@@ -1,5 +1,5 @@
/* graph_analysis.c
* Graphic Analysis addition for ethereal
*
* $Id$
*
@@ -73,7 +73,7 @@
/* XXX FIXME */
/* GTK-1.x does not have GDK_IS_DRAWABLE so just define is as always being true
* so that ethereal compiles.
* At later stage we should implement it as a real fallback for gtk-1.x
* but for the time being us very few gtk-1.2 users at elast can compile.
*/
@@ -564,7 +564,7 @@ on_save_bt_clicked (GtkButton *button _U_,
return;
}
- save_to_file_w = gtk_file_selection_new("Ethereal: Save graph to file");
+ save_to_file_w = gtk_file_selection_new("Wireshark: Save graph to file");
/* Container for each row of widgets */
vertb = gtk_vbox_new(FALSE, 0);
@@ -1,5 +1,5 @@
/* graph_analysis.c
- * Graphic Analysis addition for ethereal
+ * Graphic Analysis addition for Wireshark
*
* $Id$
@@ -73,7 +73,7 @@
/* XXX FIXME */
/* GTK-1.x does not have GDK_IS_DRAWABLE so just define is as always being true
- * so that ethereal compiles.
+ * so that Wireshark compiles.
* At later stage we should implement it as a real fallback for gtk-1.x
* but for the time being us very few gtk-1.2 users at elast can compile.